package com.mudu.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mudu.base.controller.BaseController;
import com.mudu.base.domain.AjaxResult;
import com.mudu.entity.ASafeBmxx;
import com.mudu.service.ASafeBmxxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 风险库部门信息表(ASafeBmxx)表控制层
 *
 * @author wu
 * @since 2024-02-26 10:43:21
 */
@RestController
@RequestMapping("pharmaceuticals/aSafeBmxx")
@Api(tags = "风险库部门信息表")
@Transactional(rollbackFor = Exception.class)
public class ASafeBmxxController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private ASafeBmxxService aSafeBmxxService;

    /**
     * 分页条件查询所有数据
     *
     * @param page      分页条件
     * @param aSafeBmxx 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询风险库部门信息表", response = ASafeBmxx.class)
    public AjaxResult page(Page<ASafeBmxx> page, ASafeBmxx aSafeBmxx) {
        return success(aSafeBmxxService.page(page, new QueryWrapper<>(aSafeBmxx)));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条风险库部门信息表", response = ASafeBmxx.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(aSafeBmxxService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param aSafeBmxx 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增风险库部门信息表", response = ASafeBmxx.class)
    public AjaxResult insert(@RequestBody ASafeBmxx aSafeBmxx) {
        return success(aSafeBmxxService.save(aSafeBmxx));
    }

    /**
     * 修改数据
     *
     * @param aSafeBmxx 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改风险库部门信息表")
    public AjaxResult update(@RequestBody ASafeBmxx aSafeBmxx) {
        return success(aSafeBmxxService.updateById(aSafeBmxx));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除风险库部门信息表")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(aSafeBmxxService.removeByIds(idList));
    }
}

